@@ -39,7 +39,8 @@ loadConstants <- function(env) {
                                            FLAT_FAMILY_NAME, GAMMA_FAMILY_NAME, INVGAMMA_FAMILY_NAME,
                                            WISHART_FAMILY_NAME, INVWISHART_FAMILY_NAME);
   env$SUPPORTED_UNMODELED_COEFFICIENT_FAMILY_NAMES <- c(NONE_TYPE_NAME, FLAT_FAMILY_NAME, NORMAL_FAMILY_NAME);
-  env$SUPPORTED_COMMON_SCALE_FAMILY_NAMES <- c(NONE_TYPE_NAME, FLAT_FAMILY_NAME, POINT_FAMILY_NAME);
+  env$SUPPORTED_COMMON_SCALE_FAMILY_NAMES <- c(NONE_TYPE_NAME, FLAT_FAMILY_NAME, POINT_FAMILY_NAME,
+                                               INVGAMMA_FAMILY_NAME);
   env$UNIVARIATE_FAMILY_NAMES <- c(GAMMA_FAMILY_NAME, INVGAMMA_FAMILY_NAME);
   env$MULTIVARIATE_FAMILY_NAMES <- c(WISHART_FAMILY_NAME, INVWISHART_FAMILY_NAME);
   env$ALL_FAMILY_NAMES <- c(UNIVARIATE_FAMILY_NAMES, MULTIVARIATE_FAMILY_NAMES);
